@@ -28,13 +28,9 @@ class MP:
 
         if access_data["status"] == 200:
             self.__access_data = access_data["response"]
-        else:
-            self.__access_data = None
-        
-        if self.__access_data is not None and "access_token" in self.__access_data:
             return  self.__access_data["access_token"]
         else:
-            return None
+            raise Exception(json.dumps(access_data))
         
     """
     Get information for specific payment
@@ -43,7 +39,10 @@ class MP:
 
     """    
     def get_payment_info(self, id):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
         
         payment_info = self.__rest_client.get("/collections/notifications/"+id+"?access_token="+access_token)
         return payment_info
@@ -55,7 +54,10 @@ class MP:
 
     """    
     def refund_payment(self, id):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
 
         refund_status = {"status":"refunded"}
         
@@ -69,7 +71,10 @@ class MP:
 
     """    
     def cancel_payment(self, id):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
 
         cancel_status = {"status":"cancelled"}
         
@@ -85,7 +90,10 @@ class MP:
 
     """
     def search_payment(self, filters, offset=0, limit=0):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
 
         filters["access_token"] = access_token
         filters["offset"] = offset
@@ -101,7 +109,10 @@ class MP:
 
     """
     def create_preference(self, preference):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
 
         preference_result = self.__rest_client.post("/checkout/preferences?access_token="+access_token, preference)
         return preference_result
@@ -114,7 +125,10 @@ class MP:
 
     """
     def update_preference(self, id, preference):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
         
         preference_result = self.__rest_client.put("/checkout/preferences/"+id+"?access_token="+access_token, preference)
         return preference_result
@@ -127,7 +141,10 @@ class MP:
 
     """
     def get_preference(self, id):
-        access_token = self.__get_access_token()
+        try:
+            access_token = self.__get_access_token()
+        except Exception as e:
+            return e
         
         preference_result = self.__rest_client.get("/checkout/preferences/"+id+"?access_token="+access_token)
         return preference_result
